package
Version:
v0.1.159
Opens a new window with list of versions in this module.
Published: Jul 13, 2026
License: MIT
Opens a new window with license information.
Imports: 7
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Input struct {
BlockedPreconditions []precondition
CandidateBoundaries []candidateBoundary
CheckedScope string
ChildReports []childReport
DoctorID string
Mode string
NonClaims []string
OwnerRoutes []ownerRoute
StaleAuthority staleAuthority
TouchedRuleIDs []string
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.